@@ -16,6 +16,7 @@ from bdtime import Time
 from .django import get_model_max_id_in_db
 from openpyxl import Workbook
 import os
+from django.conf import settings
 
 
 # --- 初始化环境 ---
@@ -139,16 +140,11 @@ class ExportCsvMixin:
     export_as_csv.icon = 'fas fa-download'
 
 
-# class ShowListPerPageMixin:
-#     def show_list_per_page(self, request, queryset, model=None):
-#         if model is None:
-#             meta = self.model._meta
-#         else:
-#             meta = model._meta
-#         print(1)
-#         return redirect('.')
-#
-#     show_list_per_page.short_description = "展示数据"
+# --- 检测是否安装了simpleui, 以使用不同界面配置
+app_ls: list = settings.INSTALLED_APPS
+BD_USE_SIMPLEUI = True if 'simpleui' in app_ls or 'simpleuipro'in app_ls else False
+CHANGE_LIST_HTML_PATH = "entities/mychange_list.html" if BD_USE_SIMPLEUI else "entities/basechange_list.html"
+
 
 class ImportAdmin(IDAdmin):
     """
@@ -156,7 +152,7 @@ class ImportAdmin(IDAdmin):
 
     - 不能与admin.ModelAdmin一起用!
     """
-    change_list_template = "entities/mychange_list.html"
+    change_list_template = CHANGE_LIST_HTML_PATH
 
     def import_csv(self, request):
         try:
